@@ -49,14 +49,33 @@ class MetadataClient(
 
         return resp
 
-    def get_proposal_info(self, proposal_number):
+    def get_proposal_info(self, proposal_number, instruments_list):
         logging.debug('proposal_number: {0}'.format(proposal_number))
 
         # Get PROPOSAL #id from #number
-        resp = Proposal.get_by_number(self, proposal_number)
+        resp = Proposal.get_by_number_daq_info(self, proposal_number)
+
+        if not resp['success']:
+            error_msg = '{0} >> {1}'.format(resp['info'], resp['app_info'])
+            logging.warning(error_msg)
+            return resp
 
         proposal_id = resp['data']['id']
+        proposal_instrument_identifier = resp['data']['instrument_identifier']
         logging.debug('proposal_id: {0}'.format(proposal_id))
+        logging.debug('proposal_instrument_identifier: {0}'.format(
+            proposal_instrument_identifier))
+
+        # (3) A proposal which belongs to other instrument (e.g. SA3 & HED)
+        if instruments_list is not None and \
+                proposal_instrument_identifier not in instruments_list:
+            ret_msg = "The proposal doesn't match this DAQ instance " \
+                      "configured list of allowed instruments!"
+            logging.warning(ret_msg)
+            resp['info'] = ret_msg
+            resp['app_info'] = ret_msg
+            resp['data'] = {}
+
         return resp
 
     def get_repository_by_id(self, repository_id):
