@@ -277,6 +277,69 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
         self.assert_eq_val(resp['app_info'], 'Proposal number -99 not found')
         self.assert_eq_val(resp['data'], {})
 
+    def test_get_proposal_details_success(self):
+        resp = self.mdc_client.get_proposal_info(900061, ['SPB', 'SA1'])
+
+        # Logging information
+        logging.error('resp: {0}'.format(resp))
+
+        # Expected return:
+        #
+        self.assert_eq_val(resp['app_info'], {})
+        self.assert_eq_val(resp['success'], True)
+        self.assert_eq_val(resp['info'], 'Got proposal successfully')
+
+        prop_info = resp['data']
+
+        self.assertEqual(prop_info['id'], -2)
+        self.assertEqual(prop_info['number'], 900061)
+        self.assertEqual(prop_info['title'],
+                         'DO NOT DELETE - CONTROLS TEST PROPOSAL 900061')
+        self.assertEqual(prop_info['abstract'], '')
+        self.assertEqual(prop_info['proposal_folder'], 'p900061')
+        self.assertEqual(prop_info['def_proposal_path'],
+                         '/gpfs/exfel/exp/SPB/200030/p900061/raw')
+        self.assertEqual(prop_info['doi'], '10.0850/XFEL.EU-DATA-900061-00')
+        self.assertEqual(prop_info['url'],
+                         'https://www.xfel.eu/cas_robot_framework_test')
+        self.assertEqual(prop_info['instrument_id'], 1)
+        self.assertEqual(prop_info['instrument_cycle_id'], -1)
+        self.assertEqual(prop_info['principal_investigator_id'], -7)
+        self.assertEqual(prop_info['main_proposer_id'], -7)
+        self.assertEqual(prop_info['local_contact_id'], None)
+        # self.assertEqual(prop_info['orig_repository_id'], 103)
+        # self.assertEqual(prop_info['last_run'], 422)
+        # self.assertEqual(prop_info['begin_at'], '2021-06-02T17:42:...')
+        # self.assertEqual(prop_info['end_at'], '2021-06-09T17:42:...')
+        # self.assertEqual(prop_info['release_at'], '2024-06-09T17:42:...')
+        # self.assertEqual(prop_info['num_delivered_shifts'], None)
+        # self.assertEqual(prop_info['num_preparation_shifts'], None)
+        # self.assertEqual(prop_info['flg_public'], False)
+        self.assertEqual(prop_info['flg_proposal_system'], 'L')
+        # self.assertEqual(prop_info['flg_preferred_data_output'], 'R')
+        self.assertEqual(prop_info['flg_available'], True)
+        # self.assertEqual(prop_info['flg_auto_run_quality'], -1)
+        # self.assertEqual(prop_info['flg_cloneable_status'], 'NC')
+        self.assertEqual(prop_info['flg_beamtime_status'], 'R')
+        # self.assertEqual(prop_info['beamtime_start_at'], None)
+        # self.assertEqual(prop_info['beamtime_end_at'], None)
+        # self.assertEqual(prop_info['description'], '???')
+
+        self.assertEqual(prop_info['instrument_identifier'], 'SPB')
+
+    def test_get_proposal_details_error_instruments(self):
+        resp = self.mdc_client.get_proposal_info(900061, ['SA1', 'SA2', 'SA3'])
+
+        # Logging information
+        logging.error('resp: {0}'.format(resp))
+
+        # Expected return:
+        #
+        self.assert_eq_val(resp['info'], "The proposal doesn\'t match this DAQ instance configured list of allowed instruments!")  # noqa
+        self.assert_eq_val(resp['success'], True)
+        self.assert_eq_val(resp['app_info'], "The proposal doesn\'t match this DAQ instance configured list of allowed instruments!")  # noqa
+        self.assert_eq_val(resp['data'], {})
+
     def test_register_run_with_invalid_keys(self):
         experiment_id = None
         sample_id = None
